package ifneeded eltclsh 1.20 [list load [file join /usr/local/lib/tcl libeltclsh[info sharedlibextension]]]\n[list source [file join $dir version.tcl]]\n[list source [file join $dir tools.tcl]]\n[list source [file join $dir complete.tcl]]\n[list source [file join $dir init.tcl]]
